DirectoryMoveOperation

Enum DirectoryMoveOperation 

pub enum DirectoryMoveOperation {
    CreatingDirectory {
        target_path: PathBuf,
    },
    CopyingFile {
        target_path: PathBuf,
        progress: FileProgress,
    },
    CreatingSymbolicLink {
        destination_symbolic_link_file_path: PathBuf,
    },
    RemovingSourceDirectory,
}
Describes a directory move operation.

Used in progress reporting in move_directory_with_progress.

Variants



CreatingDirectory

Describes a directory creation operation.

Fields

target_path: PathBuf

Path of the directory that is being created.



CopyingFile

Describes a file being copied. For more precise copying progress, see the progress field.

Fields

target_path: PathBuf

Path of the file is being created.

progress: FileProgress

Progress of the file operation.

Describes a symbolic link being created.

Fields

destination_symbolic_link_file_path: PathBuf

Path to the symlink being created.



RemovingSourceDirectory

Describes removal of the source directory. This happens at the very end when moving a directory.