DirectoryCopyOptions

Struct DirectoryCopyOptions 

pub struct DirectoryCopyOptions {
    pub destination_directory_rule: DestinationDirectoryRule,
    pub copy_depth_limit: DirectoryCopyDepthLimit,
    pub symlink_behaviour: SymlinkBehaviour,
    pub broken_symlink_behaviour: BrokenSymlinkBehaviour,
}
Options that influence the copy_directory function.

Fields

destination_directory_rule: DestinationDirectoryRule

Specifies whether you allow the destination directory to exist before copying and whether it must be empty or not. If you allow a non-empty destination directory, you may also specify how to behave for existing destination files and sub-directories.

See DestinationDirectoryRule for more details and examples.

copy_depth_limit: DirectoryCopyDepthLimit

Maximum depth of the source directory to copy over to the destination.

symlink_behaviour: SymlinkBehaviour

Sets the behaviour for symbolic links when copying a directory.

broken_symlink_behaviour: BrokenSymlinkBehaviour

Sets the behaviour for broken symbolic links when copying a directory.