DirectoryCopyWithProgressOptions

Struct DirectoryCopyWithProgressOptions 

pub struct DirectoryCopyWithProgressOptions {
    pub destination_directory_rule: DestinationDirectoryRule,
    pub copy_depth_limit: DirectoryCopyDepthLimit,
    pub symlink_behaviour: SymlinkBehaviour,
    pub broken_symlink_behaviour: BrokenSymlinkBehaviour,
    pub read_buffer_size: usize,
    pub write_buffer_size: usize,
    pub progress_update_byte_interval: u64,
}
Options that influence the copy_directory_with_progress function.

Fields

destination_directory_rule: DestinationDirectoryRule

Specifies whether you allow the destination directory to exist before copying, and whether you require it to be empty. If you allow a non-empty destination directory, you may also specify how to handle existing destination files and sub-directories.

See DestinationDirectoryRule documentation for more details and examples.

copy_depth_limit: DirectoryCopyDepthLimit

Maximum depth of the source directory to copy.

symlink_behaviour: SymlinkBehaviour

Sets the behaviour for symbolic links when copying a directory.

broken_symlink_behaviour: BrokenSymlinkBehaviour

Sets the behaviour for broken symbolic links when copying a directory.

read_buffer_size: usize

Internal buffer size used for reading from source files.

Defaults to 64 KiB.

write_buffer_size: usize

Internal buffer size used for writing to destination files.

Defaults to 64 KiB.

progress_update_byte_interval: u64

Minimum number of bytes written between two consecutive progress reports.

Defaults to 512 KiB.

Note that the real reporting interval can be larger (see copy_directory_with_progress for more info).