DirectoryMoveByCopyOptions

Struct DirectoryMoveByCopyOptions 

pub struct DirectoryMoveByCopyOptions {
    pub symlink_behaviour: SymlinkBehaviour,
    pub broken_symlink_behaviour: BrokenSymlinkBehaviour,
}
Options for the copy-and-delete strategy when moving a directory.

See also: DirectoryMoveOptions and move_directory.

Fields

symlink_behaviour: SymlinkBehaviour

Sets the behaviour for symbolic links when moving a directory by copy-and-delete.

Note that setting this to SymlinkBehaviour::Follow instead of SymlinkBehaviour::Keep (keep is the default) will result in behaviour that differs than the rename method (that one will always keep symbolic links). In other words, if both strategies are enabled and this is changed from the default, you will need to look at which strategy was used after the move to discern whether symbolic links were actually preserved or not.

This has the same impact as the symlink_behaviour option under DirectoryCopyOptions.

broken_symlink_behaviour: BrokenSymlinkBehaviour

Sets the behaviour for broken symbolic links when moving a directory by copy-and-delete.

This has the same impact as the broken_symlink_behaviour option under DirectoryCopyOptions.