DirectoryMoveProgress

Struct DirectoryMoveProgress 

pub struct DirectoryMoveProgress {
    pub bytes_total: u64,
    pub bytes_finished: u64,
    pub files_moved: usize,
    pub directories_created: usize,
    pub current_operation: DirectoryMoveOperation,
    pub current_operation_index: usize,
    pub total_operations: usize,
}
Represents the progress of moving a directory.

Used to report directory moving progress to a user-provided closure, see move_directory_with_progress.

Fields

bytes_total: u64

Number of bytes that need to be moved for the directory move to be complete.

bytes_finished: u64

Number of bytes that have been moved so far.

files_moved: usize

Number of files that have been moved so far.

If the copy-and-delete strategy is used under the hood, this can instead mean how many files have been copied so far (deletion will come at the end). For more information, see DirectoryMoveStrategy.

directories_created: usize

Number of directories that have been created so far.

current_operation: DirectoryMoveOperation

The current operation being performed.

current_operation_index: usize

The index of the current operation (starts at 0, goes to total_operations - 1).

total_operations: usize

The total number of operations that need to be performed to move the requested directory.

A single operation is one of (see DirectoryMoveProgress):

  • copying a file,
  • creating a directory or
  • removing the source directory (at the very end).