DirectoryMoveWithProgressByCopyOptions

Struct DirectoryMoveWithProgressByCopyOptions 

pub struct DirectoryMoveWithProgressByCopyOptions {
    pub symlink_behaviour: SymlinkBehaviour,
    pub broken_symlink_behaviour: BrokenSymlinkBehaviour,
    pub read_buffer_size: usize,
    pub write_buffer_size: usize,
    pub progress_update_byte_interval: u64,
}
Options for the copy-and-delete strategy when configuring a directory move with progress tracking.

See also: DirectoryMoveWithProgressOptions and move_directory_with_progress.

Fields

symlink_behaviour: SymlinkBehaviour

Sets the behaviour for symbolic links when moving a directory by copy-and-delete.

Note that setting this to SymlinkBehaviour::Follow instead of SymlinkBehaviour::Keep (keep is the default) will result in behaviour that differs than the rename method (that one will always keep symbolic links). In other words, if both strategies are enabled and this is changed from the default, you will need to look at which strategy was used after the move to discern whether symbolic links were actually preserved or not.

This has the same impact as the symlink_behaviour option under DirectoryCopyWithProgressOptions.

broken_symlink_behaviour: BrokenSymlinkBehaviour

Sets the behaviour for broken symbolic links when moving a directory by copy-and-delete.

This has the same impact as the broken_symlink_behaviour option under DirectoryCopyWithProgressOptions.

read_buffer_size: usize

Internal buffer size used for reading from source files.

Defaults to 64 KiB.

write_buffer_size: usize

Internal buffer size used for writing to destination files.

Defaults to 64 KiB.

progress_update_byte_interval: u64

Minimum number of bytes written between two consecutive progress reports.

Defaults to 512 KiB.

Note that the real reporting interval can be larger.