DirectoryMoveWithProgressOptions

Struct DirectoryMoveWithProgressOptions 

pub struct DirectoryMoveWithProgressOptions {
    pub destination_directory_rule: DestinationDirectoryRule,
    pub allowed_strategies: DirectoryMoveWithProgressAllowedStrategies,
}
Options that influence the move_directory_with_progress function.

destination_directory_rule considerations

If you allow the destination directory to exist and be non-empty, source directory contents will be merged (!) into the destination directory. This is not the default, and you should probably consider the consequences very carefully before using that option.

Fields

destination_directory_rule: DestinationDirectoryRule

Specifies whether you allow the destination directory to exist before moving and whether it must be empty or not.

If you allow a non-empty destination directory, you may also specify whether you allow destination files or subdirectories to already exist (and be overwritten).

See DestinationDirectoryRule for more details and examples.

allowed_strategies: DirectoryMoveWithProgressAllowedStrategies

Sets the allowed directory move strategies. Per-strategy options are also configured here.