pub enum DirectoryEmptinessScanError {
NotFound {
path: PathBuf,
},
NotADirectory {
path: PathBuf,
},
UnableToReadDirectory {
directory_path: PathBuf,
error: Error,
},
UnableToReadDirectoryEntry {
directory_path: PathBuf,
error: Error,
},
}Expand description
An error that can occur when checking whether a directory is empty
(see is_directory_empty).
Variants
NotFound
The provided directory path to scan doesn’t exist.
NotADirectory
The provided directory path exists, but is not a directory.
UnableToReadDirectory
The provided directory path is a directory, but could not be read due to an IO error.
The inner std::io::Error will likely describe a more precise cause of this error.
Fields
UnableToReadDirectoryEntry
A directory contains an entry (i.e. directory or file) that could not be read due to an IO error.
The inner std::io::Error will likely describe a more precise cause of this error.