FileCopyFinished

Enum FileCopyFinished 

pub enum FileCopyFinished {
    Created {
        bytes_copied: u64,
    },
    Overwritten {
        bytes_copied: u64,
    },
    Skipped,
}
Results of a successful file copy operation.

Returned from: copy_file and copy_file_with_progress.

Variants



Created

The destination file did not exist prior to the operation. The file was freshly created and written to.

Fields

bytes_copied: u64

Number of bytes written to the file.



Overwritten

The destination file already existed, and was overwritten by the copy operation.

Fields

bytes_copied: u64

Number of bytes written to the file.



Skipped

The destination file already existed, and the copy operation was skipped.

This can only be returned when existing destination file behaviour is set to CollidingFileBehaviour::Skip.