FileMoveMethod

Enum FileMoveMethod 

pub enum FileMoveMethod {
    Rename,
    CopyAndDelete,
}
A method used for moving a file.

Variants



Rename

The source file was renamed to the destination file.

This is very highly performant on most file systems, to the point of being near instantaneous.



CopyAndDelete

The source file was copied to the destination, and the source file was deleted afterwards.

This is generally used only if Self::Rename is impossible, and is as fast as writes normally are.