pub enum CollidingSubDirectoryBehaviour {
Abort,
Continue,
}Expand description
Rules that dictate how existing sub-directories inside the directory copy or move destination are handled when they collide with the ones we’re trying to copy or move from the source.
See also: DestinationDirectoryRule.
Variants
Abort
An existing (colliding) destination sub-directory will cause an error.
Continue
An existing (colliding) destination sub-directory will have no effect.