pub enum DirectoryMoveOperation {
CreatingDirectory {
target_path: PathBuf,
},
CopyingFile {
target_path: PathBuf,
progress: FileProgress,
},
CreatingSymbolicLink {
destination_symbolic_link_file_path: PathBuf,
},
RemovingSourceDirectory,
}Expand description
Describes a directory move operation.
Used in progress reporting in move_directory_with_progress.
Variants
CreatingDirectory
Describes a directory creation operation.
CopyingFile
Describes a file being copied.
For more precise copying progress, see the progress field.
Fields

progress: FileProgressProgress of the file operation.
CreatingSymbolicLink
Describes a symbolic link being created.
RemovingSourceDirectory
Describes removal of the source directory. This happens at the very end when moving a directory.