pub enum DirectoryScanDepthLimit {
Unlimited,
Limited {
maximum_depth: usize,
},
}Expand description
The maximum directory scan depth option.
Used primarily in DirectoryScanner.
Variants
Unlimited
No scan depth limit.
Limited
Scan depth is limited to maximum_depth, where the value refers to
the maximum depth of the subdirectory whose contents are still listed.
Examples
maximum_depth = 0 indicates a scan that will cover only the files and directories
directly in the source directory.
~/scanned-directory
|- foo.csv
|- foo-2.csv
|- bar/
(no entries listed)Notice how contents of the ~/scanned-directory/bar/
directory are not returned in the scan when using depth 0.
maximum_depth = 1 will cover the files and directories directly in the source directory
plus one level of files and subdirectories deeper.
~/scanned-directory
|- foo.csv
|- foo-2.csv
|- bar/
|- hello-world.txt
|- bar2/
(no entries listed)Notice how contents of ~/scanned-directory/bar are listed,
but contents of ~/scanned-directory/bar/bar2 are not.