pub enum SymlinkBehaviour {
Keep,
Follow,
}Expand description
How to behave when encountering symbolic links during directory copies or moves.
Variants
Keep
Indicates the symbolic link should be preserved on the destination.
It is possible that a symbolic link cannot be created on the destination, for example in certain cases when source and destination are on different mount points, in which case an error will be returned.
In this mode, broken symbolic links will be handled with the
active BrokenSymlinkBehaviour option used alongside it.
Follow
Indicates the symbolic link should be resolved and its destination content should be copied or moved to the destination instead of preserving the symbolic link.
In this mode, broken symbolic links will always cause errors,
regardless of the active BrokenSymlinkBehaviour.