pub struct DirectoryCopyProgress {
pub bytes_total: u64,
pub bytes_finished: u64,
pub files_copied: usize,
pub symlinks_created: usize,
pub directories_created: usize,
pub current_operation: DirectoryCopyOperation,
pub current_operation_index: usize,
pub total_operations: usize,
}Expand description
Directory copying progress.
This is a fully-owned version of DirectoryCopyProgress,
where the current_operation field is borrowed.
Obtainable from a reference to DirectoryCopyProgressRef
by calling DirectoryCopyProgressRef::to_owned_progress.
Fields
bytes_total: u64Total number of bytes that need to be copied for the directory copy to be complete.
bytes_finished: u64Number of bytes that have been copied so far.
files_copied: usizeNumber of files that have been copied so far.
symlinks_created: usizeNumber of symlinks that have been (re)created so far.
If the DirectoryCopyOptions::symlink_behaviour option is set to
SymlinkBehaviour::Follow, this will always be 0.
directories_created: usizeNumber of directories that have been created so far.
current_operation: DirectoryCopyOperationThe current operation being performed.
current_operation_index: usizeThe index of the current operation.
Starts at 0, goes up to (including) total_operations - 1.
total_operations: usizeThe total number of operations that need to be performed to copy the requested directory.
A single operation is either copying a file or creating a directory,
see DirectoryCopyOperation.