DirectoryCopyProgressRef

Struct DirectoryCopyProgressRef 

pub struct DirectoryCopyProgressRef<'o> {
    pub bytes_total: u64,
    pub bytes_finished: u64,
    pub files_copied: usize,
    pub symlinks_created: usize,
    pub directories_created: usize,
    pub current_operation: &'o DirectoryCopyOperation,
    pub current_operation_index: usize,
    pub total_operations: usize,
}
Directory copying progress.

This struct is used to report progress to a user-provided closure (see usage in copy_directory_with_progress).

Note that the data inside this struct isn’t fully owned - the current_operation field is borrowed, and cloning will not have the desired effect. To obtain a fully-owned clone of this state, call DirectoryCopyProgressRef::to_owned_progress.

Fields

bytes_total: u64

Total number of bytes that need to be copied for the directory copy to be complete.

bytes_finished: u64

Number of bytes that have been copied so far.

files_copied: usize

Number of files that have been copied so far.

symlinks_created: usize

Number of symlinks that have been (re)created so far.

If the DirectoryCopyOptions::symlink_behaviour option is set to SymlinkBehaviour::Follow, this will always be 0.

directories_created: usize

Number of directories that have been created so far.

current_operation: &'o DirectoryCopyOperation

The current operation being performed.

current_operation_index: usize

The index of the current operation.

Starts at 0, goes up to (including) total_operations - 1.

total_operations: usize

The total number of operations that need to be performed to copy the requested directory.

A single operation is either copying a file or creating a directory, see DirectoryCopyOperation.

Implementations

Source

impl DirectoryCopyProgressRef<'_>

pub fn to_owned_progress(&self) -> DirectoryCopyProgress

Clones the required data from this progress struct into an DirectoryCopyProgress - this way you own the entire state.