pub struct DirectoryMoveOptions {
pub destination_directory_rule: DestinationDirectoryRule,
pub allowed_strategies: DirectoryMoveAllowedStrategies,
}Expand description
Options that influence the move_directory function.
destination_directory_rule considerations
If you allow the destination directory to exist and be non-empty, source directory contents will be merged (!) into the destination directory. This is not the default, and you should probably consider the consequences very carefully before using that option.
Fields
destination_directory_rule: DestinationDirectoryRuleSpecifies whether you allow the target directory to exist before moving and whether it must be empty or not.
If you allow a non-empty target directory, you may also specify whether you allow destination files or subdirectories to already exist (and whether you allow them to be overwritten).
See DestinationDirectoryRule for more details and examples.
allowed_strategies: DirectoryMoveAllowedStrategiesSets the allowed directory move strategies. Per-strategy options are also configured here.