pub struct DirectoryScanOptions {
pub yield_base_directory: bool,
pub maximum_scan_depth: DirectoryScanDepthLimit,
pub follow_symbolic_links: bool,
pub follow_base_directory_symbolic_link: bool,
}Expand description
Options that influence DirectoryScanner.
Fields
yield_base_directory: boolWhether to have the iterator yield the base directory as its first item or not.
maximum_scan_depth: DirectoryScanDepthLimitThe maximum directory scanning depth, see DirectoryScanDepthLimit.
follow_symbolic_links: boolIf enabled, symlinks inside the scan tree will be followed,
meaning yielded ScanEntry elements will have their paths
resolved in case of a symlink.
If a symlink cycle is detected inside the tree, an error is returned when it is encountered.
follow_base_directory_symbolic_link: boolIf enabled, and if the base directory is a symbolic link,
the iterator will first resolve the symbolic link,
then proceed with scanning the destination. If the symbolic link
does not point to a directory, an error will be returned from
the first call to iterator’s next.
If disabled, and the base directory is a symbolic link,
the iterator will either yield only the base directory
(if yield_base_directory is true), or nothing.
This has no effect if the base directory is not a symlink.