FileMoveFinished

Enum FileMoveFinished 

pub enum FileMoveFinished {
    Created {
        bytes_copied: u64,
        method: FileMoveMethod,
    },
    Overwritten {
        bytes_copied: u64,
        method: FileMoveMethod,
    },
    Skipped,
}
Information about a successful file move operation.

See also: move_file.

Variants



Created

Destination file was freshly created and the contents of the source file were moved. method will describe how the move was made.

Fields

bytes_copied: u64

The number of bytes transferred in the move (i.e. the file size).

method: FileMoveMethod

How the move was accomplished.



Overwritten

Destination file existed, and was overwritten with the contents of the source file.

Fields

bytes_copied: u64

The number of bytes transferred in the move (i.e. the file size).

method: FileMoveMethod

How the move was accomplished.



Skipped

File was not moved because the destination file already existed.

This can be returned by move_file or move_file_with_progress if options.colliding_file_behaviour is set to CollidingFileBehaviour::Skip.

Note that this means the source file still exists.