pub enum FileMoveFinished {
Created {
bytes_copied: u64,
method: FileMoveMethod,
},
Overwritten {
bytes_copied: u64,
method: FileMoveMethod,
},
Skipped,
}Expand description
Information about a successful file move operation.
See also: move_file.
Variants
Created
Destination file was freshly created and the contents of the source
file were moved. method will describe how the move was made.
Fields

method: FileMoveMethodHow the move was accomplished.
Overwritten
Destination file existed, and was overwritten with the contents of the source file.
Fields

method: FileMoveMethodHow the move was accomplished.
Skipped
File was not moved because the destination file already existed.
This can be returned by move_file or move_file_with_progress
if options.colliding_file_behaviour is set to CollidingFileBehaviour::Skip.
Note that this means the source file still exists.