pub struct FileProgress {
pub bytes_finished: u64,
pub bytes_total: u64,
}Expand description
File copying or moving progress.
Primarily used in copy_file_with_progress and move_file_with_progress.
Fields
bytes_finished: u64Current number of bytes copied or moved to the destination.
bytes_total: u64Total number of bytes that must be copied or moved to the destination to complete the copy or move operation.
This value is always smaller or at most equal to
the bytes_finished field.